#!/bin/sh -f
if [  $# != 1 ];  then
    echo 'Usage ../execflesh.sh [sge|ssh]'
    echo 'This must be invoked from FleshHist'
    exit
else
    if [ $1 != "sge" ] && [ $1 != "ssh" ]; then
	echo "$1 for the argument is invalid"
	echo "At  present ssh or sge job submission is possilbe"
	exit
    fi
fi

if [ -f ./Sparam ];  then
    sparam="./Sparam"
else
    echo "There is no ./Sparam file. You have to give the parameter file"
    echo "named Sparm specified  by SkeletonFile at Skeleton making time."
    exit
fi

##   next argument is for avoiding QA in the script
source ../Smash/setupenv.sh $0
source ./setupenv.sh  $0
#  complete name of $FLESHDIR is needed
FLESHDIR=`pwd`
export FLESHDIR
echo $FLESHDIR
source ../modparam.sh  $sparam

while [ 1 ]
do
  echo '1) Do you flesh all skeletons by' "$NCPU cpus listed in $HOSTLIST"
  echo '2) Or specify some numbers  among them  for flesh job ?'
  echo '3) Or stop here'
  echo "Enter 1, 2 or 3"
  read  job
  if [ $job = 1 ]; then
     echo "You selected 1;  Enter y, if it is correct"
     read yesno
     test "x$yesno" != "xy"  && continue
     source  ../execflesh_all.sh  $HOSTLIST $1
  elif [ $job = 2 ]; then
     source  ../execflesh_one.sh  $HOSTLIST $1
  elif [ $job = 3 ]; then
     exit 
  else
     continue
  fi
  break
done
